@@ -222,7 +222,7 @@ class Datatables(View):
             for field in self.search_fields
         ]
 
-    def get_queryset(self, filters, search_value):
+    def get_queryset(self, filters, search_value, request):
         queryset = self.model.objects.all()
         if not filters == "":
             queryset = queryset.filter(reduce(operator.and_, self.get_filters(filters)))
@@ -234,8 +234,8 @@ class Datatables(View):
         queryset = self.get_queryset(filters, search_value)
         return queryset.order_by(order)
 
-    def get_data(self, start, per_page, filters, search_value, draw, order=None):
-        queryset = self.get_queryset(filters, search_value)
+    def get_data(self, start, per_page, filters, search_value, draw, order=None, request=None):
+        queryset = self.get_queryset(filters, search_value, request)
         if order:
             queryset = self.get_ordered_queryset(filters, search_value, order)
         page = int(start / per_page) + 1
